As part of the recovery process, the drivers removes offline devices (
done by the kernel) and then tries to add them back in the rescan code.
Removing the device is like taking a sledgehammer to a nail.

Set the device as running if it is marked offline.

Signed-off-by: Raghava Aditya Renukunta <raghavaaditya.renuku...@microsemi.com>
---
 drivers/scsi/aacraid/commsup.c | 10 ++++------
 1 file changed, 4 insertions(+), 6 deletions(-)

diff --git a/drivers/scsi/aacraid/commsup.c b/drivers/scsi/aacraid/commsup.c
index ffbfd04..32b8bdb 100644
--- a/drivers/scsi/aacraid/commsup.c
+++ b/drivers/scsi/aacraid/commsup.c
@@ -1658,14 +1658,12 @@ static int _aac_reset_adapter(struct aac_dev *aac, int 
forced, u8 reset_type)
                command->scsi_done(command);
        }
        /*
         * Any Device that was already marked offline needs to be cleaned up
         */
        __shost_for_each_device(dev, host) {
-               if (!scsi_device_online(dev)) {
-                       sdev_printk(KERN_INFO, dev, "Removing offline 
device\n");
-                       scsi_remove_device(dev);
-                       scsi_device_put(dev);
-               }
+               if (!scsi_device_online(dev))
+                       scsi_device_set_state(dev, SDEV_RUNNING);
        }
        retval = 0;
 
@@ -1658,14 +1658,12 @@ static int _aac_reset_adapter(struct aac_dev *aac, int 
        }
        /*
-        * Any Device that was already marked offline needs to be cleaned up
+        * Any Device that was already marked offline needs to be marked
+        * running
         */
        __shost_for_each_device(dev, host) {
-- 
2.9.4

Reply via email to